@@ -72,6 +72,9 @@
 #'   time-to-adoption and Rogers segment classifications. The suggested variable
 #'   is "Total_Copilot_enabled_days", but any metric that indicates access or
 #'   licensing status can be used (e.g., "License_assigned_days", "Access_granted").
+#'   This parameter is optional for plot modes 1 and 2, but required for plot modes
+#'   3 and 4. When `return = "data"` and `start_metric` is provided, Rogers segment
+#'   classifications will be included in the returned data frame. Default is `NULL`.
 #' @param return Character vector specifying what to return. Valid inputs are
 #' "plot", "data", and "table". Default is "plot".
 #' @param plot_mode Integer or character string determining which plot to return.
@@ -83,6 +86,10 @@
 #'   \item 4 or "cumulative_enablement": Cumulative adoption adjusted for enablement
 #' }
 #' Default is 1.
+#' @param label Logical value to determine whether to show data point labels on
+#'   the plot for cumulative adoption curves (plot modes 1 and 4). If `TRUE`, 
+#'   both `geom_point()` and `geom_text()` are added to display data labels 
+#'   rounded to 1 decimal place above each data point. Defaults to `FALSE`.
 #'
 #' @import dplyr
 #' @import ggplot2
@@ -117,10 +124,43 @@
 #'   plot_mode = 3
 #' )
 #'
+#' # Return data with Rogers segments
+#' rogers_data <- create_rogers(
+#'   data = pq_data,
+#'   metric = "Copilot_actions_taken_in_Teams",
+#'   start_metric = "Total_Copilot_enabled_days",
+#'   return = "data"
+#' )
+#' 
+#' # Rogers adoption curve with data point labels
+#' create_rogers(
+#'   data = pq_data,
+#'   metric = "Copilot_actions_taken_in_Teams",
+#'   plot_mode = 1,
+#'   label = TRUE
+#' )
+#'
 #' @return
 #' Returns a 'ggplot' object by default when 'plot' is passed in `return`.
 #' When 'table' is passed, a summary table is returned as a data frame.
 #' When 'data' is passed, the processed data with habit classifications is returned.
+#' 
+#' When `return = "data"`, the returned data frame includes:
+#' \itemize{
+#'   \item All original columns from the input data
+#'   \item `IsHabit`: Binary indicator of whether the user has developed a habit
+#'   \item `adoption_week`: The week when the user first exhibited habitual behavior
+#'   \item `enable_week`: (if `start_metric` provided) The week when the user was first enabled
+#'   \item `weeks_to_adopt`: (if `start_metric` provided) Number of weeks from enablement to adoption
+#'   \item `RogersSegment`: (if `start_metric` provided) Rogers adoption segment classification:
+#'     \itemize{
+#'       \item "Innovators" (fastest 2.5\%)
+#'       \item "Early Adopters" (next 13.5\%)
+#'       \item "Early Majority" (next 34\%)
+#'       \item "Late Majority" (next 34\%)
+#'       \item "Laggards" (slowest 16\%)
+#'     }
+#' }
 #'
 #' @export
 
@@ -130,9 +170,10 @@ create_rogers <- function(data,
                          width = 9,
                          max_window = 12,
                          threshold = 1,
-                         start_metric,
+                         start_metric = NULL,
                          return = "plot",
-                         plot_mode = 1) {
+                         plot_mode = 1,
+                         label = FALSE) {
   
   ## Check inputs
   required_variables <- c("MetricDate", metric, "PersonId")
@@ -143,6 +184,10 @@ create_rogers <- function(data,
   
   ## Check if start_metric exists for enablement-based plots
   if (plot_mode %in% c(3, 4, "enablement", "cumulative_enablement")) {
+    if (is.null(start_metric)) {
+      stop(paste("The 'start_metric' parameter is required for plot mode", plot_mode, 
+                 "(enablement-based analysis). Please provide a metric that indicates when users gained access to the technology."))
+    }
     if (!start_metric %in% names(data)) {
       stop(paste("Column", start_metric, "not found in data for enablement-based analysis."))
     }
@@ -177,7 +222,50 @@ create_rogers <- function(data,
   
   ## Return data if requested
   if (return == "data") {
-    return(data_with_habit)
+    # Add adoption week information to the data
+    data_with_adoption <- data_with_habit %>%
+      left_join(
+        adoption_week_df %>% select(.data$PersonId, adoption_week),
+        by = "PersonId"
+      )
+    
+    # Calculate Rogers segment if start_metric is provided
+    if (!is.null(start_metric) && start_metric %in% names(data)) {
+      # Calculate enable week (first date where start_metric > 0)
+      enable_week_df <- data_with_habit %>%
+        filter(!!sym(start_metric) > 0) %>%
+        group_by(.data$PersonId) %>%
+        summarise(enable_week = min(.data$MetricDate, na.rm = TRUE), .groups = "drop")
+      
+      # Calculate Rogers segments based on time to adoption
+      rogers_segments <- adoption_week_df %>%
+        left_join(enable_week_df, by = "PersonId") %>%
+        filter(!is.na(.data$enable_week)) %>%
+        mutate(
+          weeks_to_adopt = as.numeric(difftime(.data$adoption_week, .data$enable_week, units = "weeks")),
+          adoption_delay_percent = percent_rank(.data$weeks_to_adopt),
+          RogersSegment = case_when(
+            .data$adoption_delay_percent <= 0.025 ~ "Innovators",
+            .data$adoption_delay_percent <= 0.16  ~ "Early Adopters",
+            .data$adoption_delay_percent <= 0.50  ~ "Early Majority",
+            .data$adoption_delay_percent <= 0.84  ~ "Late Majority",
+            TRUE                                  ~ "Laggards"
+          )
+        ) %>%
+        select(.data$PersonId, .data$enable_week, .data$weeks_to_adopt, .data$RogersSegment)
+      
+      # Join Rogers segments back to the data
+      data_with_adoption <- data_with_adoption %>%
+        left_join(rogers_segments, by = "PersonId")
+      
+      message(paste("Rogers segments calculated based on", start_metric))
+      message(paste("Total users with Rogers segments:", sum(!is.na(rogers_segments$RogersSegment))))
+    } else {
+      message("Note: 'start_metric' not provided. Rogers segment classification not included.")
+      message("To include Rogers segments, provide 'start_metric' parameter indicating when users gained access.")
+    }
+    
+    return(data_with_adoption)
   }
   
   ## Convert plot_mode to numeric for easier handling
@@ -211,14 +299,22 @@ create_rogers <- function(data,
         facet_wrap(as.formula(paste("~", hrvar)), scales = "free_y") +
         scale_y_continuous(labels = scales::percent_format()) +
         labs(
-          title = paste("Rogers Adoption Curve by", hrvar),
-          subtitle = paste("Cumulative adoption of", us_to_space(metric)),
+          title = "Rogers cumulative adoption curve",
+          subtitle = paste("Based on", us_to_space(metric)),
           x = "Week of Habitual Adoption",
           y = "Cumulative % of Habitual Users",
           color = hrvar,
           caption = extract_date_range(data, return = "text")
         ) +
         theme_wpa_basic()
+      
+      # Conditionally add points and labels if label = TRUE
+      if(label == TRUE){
+        plot_object <- plot_object +
+          geom_point(size = 2) +
+          geom_text(aes(label = scales::percent(round(.data$cumulative_percent, 3))), 
+                    vjust = -0.5, hjust = 0.5, size = 3, colour = "black")
+      }
     } else {
       # Overall
       rogers_curve <- adoption_week_df %>%
@@ -231,15 +327,26 @@ create_rogers <- function(data,
       
       plot_object <- ggplot(rogers_curve, aes(x = .data$adoption_week, y = .data$cumulative_percent)) +
         geom_line(size = 1.2, color = "#1c66b0") +
-        geom_point() +
         scale_y_continuous(labels = scales::percent_format()) +
         labs(
-          title = paste("Rogers Adoption Curve for", us_to_space(metric)),
+          title = "Rogers cumulative adoption curve",
+          subtitle = paste("Based on", us_to_space(metric)),
           x = "Week of Adoption",
           y = "Cumulative % of Habitual Users",
           caption = extract_date_range(data, return = "text")
         ) +
         theme_wpa_basic()
+      
+      # Conditionally add points and labels if label = TRUE
+      if(label == TRUE){
+        plot_object <- plot_object +
+          geom_point(color = "#1c66b0", size = 2) +
+          geom_text(aes(label = scales::percent(round(.data$cumulative_percent, 3))), 
+                    vjust = -0.5, hjust = 0.5, size = 3, colour = "black")
+      } else {
+        plot_object <- plot_object +
+          geom_point()
+      }
     }
     
   } else if (plot_mode == 2) {
@@ -262,12 +369,18 @@ create_rogers <- function(data,
         facet_wrap(as.formula(paste("~", hrvar)), scales = "free_y") +
         labs(
           title = paste("Weekly Rate of", us_to_space(metric), "Adoption by", hrvar),
-          subtitle = "New habitual users each week",
+          subtitle = "New habitual users each week; line indicating moving average",
           x = "Week",
           y = "New Habitual Users",
           caption = extract_date_range(data, return = "text")
         ) +
         theme_wpa_basic()
+      
+      # Conditionally add data labels if label = TRUE
+      if(label == TRUE){
+        plot_object <- plot_object +
+          geom_text(aes(label = .data$new_adopters), vjust = -0.5, hjust = 0.5, size = 3, colour = "black")
+      }
     } else {
       # Overall
       adoption_rate <- adoption_week_df %>%
@@ -283,12 +396,18 @@ create_rogers <- function(data,
         geom_line(aes(y = .data$moving_avg), color = "#0c336e", size = 1.2) +
         labs(
           title = paste("Weekly Rate of", us_to_space(metric), "Adoption"),
-          subtitle = "New habitual users identified each week",
+          subtitle = "New habitual users identified each week; line indicating moving average",
           x = "Week",
           y = "New Habitual Users",
           caption = extract_date_range(data, return = "text")
         ) +
         theme_wpa_basic()
+      
+      # Conditionally add data labels if label = TRUE
+      if(label == TRUE){
+        plot_object <- plot_object +
+          geom_text(aes(label = .data$new_adopters), vjust = -0.5, hjust = 0.5, size = 3, colour = "black")
+      }
     }
     
   } else if (plot_mode == 3) {
@@ -317,6 +436,24 @@ create_rogers <- function(data,
       count(.data$adoption_week, .data$RogersSegment_delay) %>%
       rename(new_adopters = .data$n)
     
+    # Calculate segment proportions for caption
+    segment_proportions <- adoption_week_df2 %>%
+      count(.data$RogersSegment_delay) %>%
+      mutate(
+        total = sum(.data$n),
+        percentage = round((.data$n / .data$total) * 100, 0)
+      ) %>%
+      arrange(factor(.data$RogersSegment_delay, 
+                    levels = c("Innovators", "Early Adopters", "Early Majority", "Late Majority", "Laggards")))
+    
+    # Create caption with proportions
+    proportions_text <- paste(
+      paste(segment_proportions$RogersSegment_delay, ": ", segment_proportions$percentage, "%", sep = ""),
+      collapse = "; "
+    )
+    
+    full_caption <- paste(extract_date_range(data, return = "text"), "\n", proportions_text, sep = "")
+    
     plot_object <- ggplot(weekly_segment_counts, aes(x = .data$adoption_week, y = .data$new_adopters, fill = .data$RogersSegment_delay)) +
       geom_col(position = "stack") +
       scale_fill_manual(
@@ -334,10 +471,16 @@ create_rogers <- function(data,
         x = "Week of Adoption",
         y = "Number of New Habitual Users",
         fill = "Rogers Segment",
-        caption = extract_date_range(data, return = "text")
+        caption = full_caption
       ) +
       theme_wpa_basic()
     
+    # Conditionally add data labels if label = TRUE
+    if(label == TRUE){
+      plot_object <- plot_object +
+        geom_text(aes(label = .data$new_adopters), position = position_stack(vjust = 0.5), size = 3, colour = "white")
+    }
+    
   } else if (plot_mode == 4) {
     # Cumulative Enablement-based Adoption
     enable_week_df <- data_with_habit %>%
@@ -359,16 +502,27 @@ create_rogers <- function(data,
     
     plot_object <- ggplot(cumulative_df, aes(x = .data$adoption_week, y = .data$cumulative_percent)) +
       geom_line(size = 1.2, color = "#1c66b0") +
-      geom_point() +
       scale_y_continuous(labels = scales::percent) +
       labs(
-        title = paste("Cumulative", us_to_space(metric), "Adoption Over Time (Adjusted for Enablement)"),
+        title = "Enablement-adjusted cumulative adoption curve",
+        subtitle = paste("Based on", us_to_space(metric)),
         x = "Adoption Week",
         y = "Cumulative % of Users",
         caption = extract_date_range(data, return = "text")
       ) +
       theme_wpa_basic()
     
+    # Conditionally add points and labels if label = TRUE
+    if(label == TRUE){
+      plot_object <- plot_object +
+        geom_point(color = "#1c66b0", size = 2) +
+        geom_text(aes(label = scales::percent(round(.data$cumulative_percent, 3))), 
+                  vjust = -0.5, hjust = 0.5, size = 3, colour = "black")
+    } else {
+      plot_object <- plot_object +
+        geom_point()
+    }
+    
   } else {
     stop("Invalid plot_mode. Use 1-4 or 'cumulative', 'weekly', 'enablement', 'cumulative_enablement'.")
   }
