@@ -28,11 +28,13 @@
 email_line <- function(data,
                        hrvar = "Organization",
                        mingroup = 5,
-                       return = "plot"){
+                       return = "plot",
+                       label = FALSE){
   ## Inherit arguments
   create_line(data = data,
               metric = "Email_hours",
               hrvar = hrvar,
               mingroup = mingroup,
-              return = return)
+              return = return,
+              label = label)
 }
