@@ -148,10 +148,13 @@ utils::globalVariables(
      "weeks_to_adopt",
      "adoption_delay_percent",
      "RogersSegment_delay",
+     "RogersSegment",
      "cumulative",
      "earliest_adoption",
      "latest_adoption",
      "median_adoption_week",
-     "total_adopters"
+     "total_adopters",
+     "id",
+     "segment_count"
     )
 )
\ No newline at end of file
