@@ -28,12 +28,14 @@
 meeting_line <- function(data,
                          hrvar = "Organization",
                          mingroup = 5,
-                         return = "plot"){
+                         return = "plot",
+                         label = FALSE){
 
   ## Inherit arguments
   create_line(data = data,
               metric = "Meeting_hours",
               hrvar = hrvar,
               mingroup = mingroup,
-              return = return)
+              return = return,
+              label = label)
 }
